// Generated by gmmproc 2.50.1 -- DO NOT MODIFY!
#ifndef _GSTREAMERMM_VALVE_H
#define _GSTREAMERMM_VALVE_H

#include <gstreamermmconfig.h>

#ifndef GSTREAMERMM_DISABLE_DEPRECATED


#include <glibmm/ustring.h>
#include <sigc++/sigc++.h>

// Generated by generate_plugin_gmmproc_file. Don't edit this file.


#include <gstreamermm/element.h>


#ifndef DOXYGEN_SHOULD_SKIP_THIS
using GstValve = struct _GstValve;
using GstValveClass = struct _GstValveClass;
#endif /* DOXYGEN_SHOULD_SKIP_THIS */


#ifndef DOXYGEN_SHOULD_SKIP_THIS
namespace Gst
{ class Valve_Class; } // namespace Gst
#endif //DOXYGEN_SHOULD_SKIP_THIS

namespace Gst
{

/** A Wrapper for the valve plugin.
 * Please note that not all plug-ins are available on all systems so care
 * must be taken that they exist before they are used otherwise there will
 * be errors and possibly a crash.
 *
 * @ingroup GstPlugins
 * @deprecated Plugins API is deprecated, and should not be used in a new code.
 */

class Valve
: public Gst::Element
{
  
#ifndef DOXYGEN_SHOULD_SKIP_THIS

public:
  using CppObjectType = Valve;
  using CppClassType = Valve_Class;
  using BaseObjectType = GstValve;
  using BaseClassType = GstValveClass;

  // noncopyable
  Valve(const Valve&) = delete;
  Valve& operator=(const Valve&) = delete;

private:  friend class Valve_Class;
  static CppClassType valve_class_;

protected:
  explicit Valve(const Glib::ConstructParams& construct_params);
  explicit Valve(GstValve* castitem);

#endif /* DOXYGEN_SHOULD_SKIP_THIS */

public:

  Valve(Valve&& src) noexcept;
  Valve& operator=(Valve&& src) noexcept;

  ~Valve() noexcept override;

  /** Get the GType for this class, for use with the underlying GObject type system.
   */
  static GType get_type()      G_GNUC_CONST;

#ifndef DOXYGEN_SHOULD_SKIP_THIS


  static GType get_base_type() G_GNUC_CONST;
#endif

  ///Provides access to the underlying C GObject.
  GstValve*       gobj()       { return reinterpret_cast<GstValve*>(gobject_); }

  ///Provides access to the underlying C GObject.
  const GstValve* gobj() const { return reinterpret_cast<GstValve*>(gobject_); }

  ///Provides access to the underlying C instance. The caller is responsible for unrefing it. Use when directly setting fields in structs.
  GstValve* gobj_copy();

private:

  
protected:
  Valve();
  explicit Valve(const Glib::ustring& name);

public:
  /** Creates a new valve plugin with a unique name.
   */
  
  static Glib::RefPtr<Valve> create();


  /** Creates a new valve plugin with the given name.
   */
  
  static Glib::RefPtr<Valve> create(const Glib::ustring& name);


  /** Whether to drop buffers and events or let them through.
   *
   * @return A PropertyProxy that allows you to get or set the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy< bool > property_drop() ;

/** Whether to drop buffers and events or let them through.
   *
   * @return A PropertyProxy_ReadOnly that allows you to get the value of the property,
   * or receive notification when the value of the property changes.
   */
  Glib::PropertyProxy_ReadOnly< bool > property_drop() const;


public:

public:
  //C++ methods used to invoke GTK+ virtual functions:

protected:
  //GTK+ Virtual Functions (override these to change behaviour):

  //Default Signal Handlers::


};

} // namespace Gst


namespace Glib
{
  /** A Glib::wrap() method for this object.
   *
   * @param object The C instance.
   * @param take_copy False if the result should take ownership of the C instance. True if it should take a new copy or ref.
   * @result A C++ instance that wraps this C instance.
   *
   * @relates Gst::Valve
   */
  Glib::RefPtr<Gst::Valve> wrap(GstValve* object, bool take_copy = false);
}


#endif // GSTREAMERMM_DISABLE_DEPRECATED


#endif /* _GSTREAMERMM_VALVE_H */

