// Generated by gmmproc 2.50.1 -- DO NOT MODIFY!


#include <gstreamermmconfig.h>
#ifndef GSTREAMERMM_DISABLE_DEPRECATED


#include <glibmm.h>

#include <gstreamermm/audioconvert.h>
#include <gstreamermm/private/audioconvert_p.h>


// Generated by generate_plugin_gmmproc_file. Don't edit this file.


extern "C"
{

static GType gst_audio_dither_method_get_type()
{
  static GType const type = g_type_from_name("GstAudioDitherMethod");
  return type;
}

static GType gst_audio_noise_shaping_method_get_type()
{
  static GType const type = g_type_from_name("GstAudioNoiseShapingMethod");
  return type;
}

GType gst_audio_convert_gstreamermm_get_type()
{
  static GType type = 0;
  GstElementFactory* factory = 0;
  GstPluginFeature* feature = 0;

  if(!type)
  {
    factory = gst_element_factory_find("audioconvert");
    // Make sure that the feature is actually loaded:
    if(factory)
    {
      feature =
        gst_plugin_feature_load(GST_PLUGIN_FEATURE(factory));

      g_object_unref(factory);
      factory = GST_ELEMENT_FACTORY(feature);
      type = gst_element_factory_get_element_type(factory);
      g_object_unref(factory);
    }
  }

  return type;
}

} // extern "C"

namespace Gst
{

AudioConvert::AudioConvert()
: // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gst::BaseTransform(Glib::ConstructParams(audioconvert_class_.init(), "name",static_cast<char*>(0), nullptr))
{}

AudioConvert::AudioConvert(const Glib::ustring& name)
: // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gst::BaseTransform(Glib::ConstructParams(audioconvert_class_.init(), "name",name.c_str(), nullptr))
{}

}

namespace
{
} // anonymous namespace

// static
GType Glib::Value<Gst::AudioDitherMethod>::value_type()
{
  return gst_audio_dither_method_get_type();
}

// static
GType Glib::Value<Gst::AudioNoiseShapingMethod>::value_type()
{
  return gst_audio_noise_shaping_method_get_type();
}


namespace Glib
{

Glib::RefPtr<Gst::AudioConvert> wrap(GstAudioConvert* object, bool take_copy)
{
  return Glib::RefPtr<Gst::AudioConvert>( dynamic_cast<Gst::AudioConvert*> (Glib::wrap_auto ((GObject*)(object), take_copy)) );
  //We use dynamic_cast<> in case of multiple inheritance.
}

} /* namespace Glib */


namespace Gst
{


/* The *_Class implementation: */

const Glib::Class& AudioConvert_Class::init()
{
  if(!gtype_) // create the GType if necessary
  {
    // Glib::Class has to know the class init function to clone custom types.
    class_init_func_ = &AudioConvert_Class::class_init_function;

    // This is actually just optimized away, apparently with no harm.
    // Make sure that the parent type has been created.
    //CppClassParent::CppObjectType::get_type();

    // Create the wrapper type, with the same class/instance size as the base type.
    register_derived_type(gst_audio_convert_gstreamermm_get_type());

    // Add derived versions of interfaces, if the C type implements any interfaces:

  }

  return *this;
}


void AudioConvert_Class::class_init_function(void* g_class, void* class_data)
{
  const auto klass = static_cast<BaseClassType*>(g_class);
  CppClassParent::class_init_function(klass, class_data);


}


Glib::ObjectBase* AudioConvert_Class::wrap_new(GObject* object)
{
  return new AudioConvert((GstAudioConvert*)object);
}


/* The implementation: */

GstAudioConvert* AudioConvert::gobj_copy()
{
  reference();
  return gobj();
}

AudioConvert::AudioConvert(const Glib::ConstructParams& construct_params)
:
  Gst::BaseTransform(construct_params)
{

}

AudioConvert::AudioConvert(GstAudioConvert* castitem)
:
  Gst::BaseTransform((GstBaseTransform*)(castitem))
{}


AudioConvert::AudioConvert(AudioConvert&& src) noexcept
: Gst::BaseTransform(std::move(src))
{}

AudioConvert& AudioConvert::operator=(AudioConvert&& src) noexcept
{
  Gst::BaseTransform::operator=(std::move(src));
  return *this;
}


AudioConvert::~AudioConvert() noexcept
{}


AudioConvert::CppClassType AudioConvert::audioconvert_class_; // initialize static member

GType AudioConvert::get_type()
{
  return audioconvert_class_.init().get_type();
}


GType AudioConvert::get_base_type()
{
  return gst_audio_convert_gstreamermm_get_type();
}


Glib::RefPtr<AudioConvert> AudioConvert::create()
{
  return Glib::RefPtr<AudioConvert>( new AudioConvert() );
}

Glib::RefPtr<AudioConvert> AudioConvert::create(const Glib::ustring& name)
{
  return Glib::RefPtr<AudioConvert>( new AudioConvert(name) );
}


Glib::PropertyProxy< Gst::AudioDitherMethod > AudioConvert::property_dithering() 
{
  return Glib::PropertyProxy< Gst::AudioDitherMethod >(this, "dithering");
}

Glib::PropertyProxy_ReadOnly< Gst::AudioDitherMethod > AudioConvert::property_dithering() const
{
  return Glib::PropertyProxy_ReadOnly< Gst::AudioDitherMethod >(this, "dithering");
}

Glib::PropertyProxy< Gst::AudioNoiseShapingMethod > AudioConvert::property_noise_shaping() 
{
  return Glib::PropertyProxy< Gst::AudioNoiseShapingMethod >(this, "noise-shaping");
}

Glib::PropertyProxy_ReadOnly< Gst::AudioNoiseShapingMethod > AudioConvert::property_noise_shaping() const
{
  return Glib::PropertyProxy_ReadOnly< Gst::AudioNoiseShapingMethod >(this, "noise-shaping");
}


} // namespace Gst

#endif // GSTREAMERMM_DISABLE_DEPRECATED


