// Generated by gmmproc 2.50.1 -- DO NOT MODIFY!


#include <gstreamermmconfig.h>
#ifndef GSTREAMERMM_DISABLE_DEPRECATED


#include <glibmm.h>

#include <gstreamermm/audiotestsrc.h>
#include <gstreamermm/private/audiotestsrc_p.h>


// Generated by generate_plugin_gmmproc_file. Don't edit this file.


extern "C"
{

static GType gst_audio_test_src_wave_get_type()
{
  static GType const type = g_type_from_name("GstAudioTestSrcWave");
  return type;
}

GType gst_audio_test_src_gstreamermm_get_type()
{
  static GType type = 0;
  GstElementFactory* factory = 0;
  GstPluginFeature* feature = 0;

  if(!type)
  {
    factory = gst_element_factory_find("audiotestsrc");
    // Make sure that the feature is actually loaded:
    if(factory)
    {
      feature =
        gst_plugin_feature_load(GST_PLUGIN_FEATURE(factory));

      g_object_unref(factory);
      factory = GST_ELEMENT_FACTORY(feature);
      type = gst_element_factory_get_element_type(factory);
      g_object_unref(factory);
    }
  }

  return type;
}

} // extern "C"

namespace Gst
{

AudioTestSrc::AudioTestSrc()
: // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gst::BaseSrc(Glib::ConstructParams(audiotestsrc_class_.init(), "name",static_cast<char*>(0), nullptr))
{}

AudioTestSrc::AudioTestSrc(const Glib::ustring& name)
: // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gst::BaseSrc(Glib::ConstructParams(audiotestsrc_class_.init(), "name",name.c_str(), nullptr))
{}

}

namespace
{
} // anonymous namespace

// static
GType Glib::Value<Gst::AudioTestSrcWave>::value_type()
{
  return gst_audio_test_src_wave_get_type();
}


namespace Glib
{

Glib::RefPtr<Gst::AudioTestSrc> wrap(GstAudioTestSrc* object, bool take_copy)
{
  return Glib::RefPtr<Gst::AudioTestSrc>( dynamic_cast<Gst::AudioTestSrc*> (Glib::wrap_auto ((GObject*)(object), take_copy)) );
  //We use dynamic_cast<> in case of multiple inheritance.
}

} /* namespace Glib */


namespace Gst
{


/* The *_Class implementation: */

const Glib::Class& AudioTestSrc_Class::init()
{
  if(!gtype_) // create the GType if necessary
  {
    // Glib::Class has to know the class init function to clone custom types.
    class_init_func_ = &AudioTestSrc_Class::class_init_function;

    // This is actually just optimized away, apparently with no harm.
    // Make sure that the parent type has been created.
    //CppClassParent::CppObjectType::get_type();

    // Create the wrapper type, with the same class/instance size as the base type.
    register_derived_type(gst_audio_test_src_gstreamermm_get_type());

    // Add derived versions of interfaces, if the C type implements any interfaces:

  }

  return *this;
}


void AudioTestSrc_Class::class_init_function(void* g_class, void* class_data)
{
  const auto klass = static_cast<BaseClassType*>(g_class);
  CppClassParent::class_init_function(klass, class_data);


}


Glib::ObjectBase* AudioTestSrc_Class::wrap_new(GObject* object)
{
  return new AudioTestSrc((GstAudioTestSrc*)object);
}


/* The implementation: */

GstAudioTestSrc* AudioTestSrc::gobj_copy()
{
  reference();
  return gobj();
}

AudioTestSrc::AudioTestSrc(const Glib::ConstructParams& construct_params)
:
  Gst::BaseSrc(construct_params)
{

}

AudioTestSrc::AudioTestSrc(GstAudioTestSrc* castitem)
:
  Gst::BaseSrc((GstBaseSrc*)(castitem))
{}


AudioTestSrc::AudioTestSrc(AudioTestSrc&& src) noexcept
: Gst::BaseSrc(std::move(src))
{}

AudioTestSrc& AudioTestSrc::operator=(AudioTestSrc&& src) noexcept
{
  Gst::BaseSrc::operator=(std::move(src));
  return *this;
}


AudioTestSrc::~AudioTestSrc() noexcept
{}


AudioTestSrc::CppClassType AudioTestSrc::audiotestsrc_class_; // initialize static member

GType AudioTestSrc::get_type()
{
  return audiotestsrc_class_.init().get_type();
}


GType AudioTestSrc::get_base_type()
{
  return gst_audio_test_src_gstreamermm_get_type();
}


Glib::RefPtr<AudioTestSrc> AudioTestSrc::create()
{
  return Glib::RefPtr<AudioTestSrc>( new AudioTestSrc() );
}

Glib::RefPtr<AudioTestSrc> AudioTestSrc::create(const Glib::ustring& name)
{
  return Glib::RefPtr<AudioTestSrc>( new AudioTestSrc(name) );
}


Glib::PropertyProxy< int > AudioTestSrc::property_samplesperbuffer() 
{
  return Glib::PropertyProxy< int >(this, "samplesperbuffer");
}

Glib::PropertyProxy_ReadOnly< int > AudioTestSrc::property_samplesperbuffer() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "samplesperbuffer");
}

Glib::PropertyProxy< Gst::AudioTestSrcWave > AudioTestSrc::property_wave() 
{
  return Glib::PropertyProxy< Gst::AudioTestSrcWave >(this, "wave");
}

Glib::PropertyProxy_ReadOnly< Gst::AudioTestSrcWave > AudioTestSrc::property_wave() const
{
  return Glib::PropertyProxy_ReadOnly< Gst::AudioTestSrcWave >(this, "wave");
}

Glib::PropertyProxy< double > AudioTestSrc::property_freq() 
{
  return Glib::PropertyProxy< double >(this, "freq");
}

Glib::PropertyProxy_ReadOnly< double > AudioTestSrc::property_freq() const
{
  return Glib::PropertyProxy_ReadOnly< double >(this, "freq");
}

Glib::PropertyProxy< double > AudioTestSrc::property_volume() 
{
  return Glib::PropertyProxy< double >(this, "volume");
}

Glib::PropertyProxy_ReadOnly< double > AudioTestSrc::property_volume() const
{
  return Glib::PropertyProxy_ReadOnly< double >(this, "volume");
}

Glib::PropertyProxy< bool > AudioTestSrc::property_is_live() 
{
  return Glib::PropertyProxy< bool >(this, "is-live");
}

Glib::PropertyProxy_ReadOnly< bool > AudioTestSrc::property_is_live() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "is-live");
}

Glib::PropertyProxy< gint64 > AudioTestSrc::property_timestamp_offset() 
{
  return Glib::PropertyProxy< gint64 >(this, "timestamp-offset");
}

Glib::PropertyProxy_ReadOnly< gint64 > AudioTestSrc::property_timestamp_offset() const
{
  return Glib::PropertyProxy_ReadOnly< gint64 >(this, "timestamp-offset");
}

Glib::PropertyProxy< bool > AudioTestSrc::property_can_activate_push() 
{
  return Glib::PropertyProxy< bool >(this, "can-activate-push");
}

Glib::PropertyProxy_ReadOnly< bool > AudioTestSrc::property_can_activate_push() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "can-activate-push");
}

Glib::PropertyProxy< bool > AudioTestSrc::property_can_activate_pull() 
{
  return Glib::PropertyProxy< bool >(this, "can-activate-pull");
}

Glib::PropertyProxy_ReadOnly< bool > AudioTestSrc::property_can_activate_pull() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "can-activate-pull");
}


} // namespace Gst

#endif // GSTREAMERMM_DISABLE_DEPRECATED


