// Generated by gmmproc 2.50.1 -- DO NOT MODIFY!


#include <gstreamermmconfig.h>
#ifndef GSTREAMERMM_DISABLE_DEPRECATED


#include <glibmm.h>

#include <gstreamermm/queue2.h>
#include <gstreamermm/private/queue2_p.h>


// Generated by generate_plugin_gmmproc_file. Don't edit this file.


extern "C"
{

GType gst_queue2_gstreamermm_get_type()
{
  static GType type = 0;
  GstElementFactory* factory = 0;
  GstPluginFeature* feature = 0;

  if(!type)
  {
    factory = gst_element_factory_find("queue2");
    // Make sure that the feature is actually loaded:
    if(factory)
    {
      feature =
        gst_plugin_feature_load(GST_PLUGIN_FEATURE(factory));

      g_object_unref(factory);
      factory = GST_ELEMENT_FACTORY(feature);
      type = gst_element_factory_get_element_type(factory);
      g_object_unref(factory);
    }
  }

  return type;
}

} // extern "C"

namespace Gst
{

Queue2::Queue2()
: // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gst::Element(Glib::ConstructParams(queue2_class_.init(), "name",static_cast<char*>(0), nullptr))
{}

Queue2::Queue2(const Glib::ustring& name)
: // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gst::Element(Glib::ConstructParams(queue2_class_.init(), "name",name.c_str(), nullptr))
{}

}

namespace
{
} // anonymous namespace


namespace Glib
{

Glib::RefPtr<Gst::Queue2> wrap(GstQueue2* object, bool take_copy)
{
  return Glib::RefPtr<Gst::Queue2>( dynamic_cast<Gst::Queue2*> (Glib::wrap_auto ((GObject*)(object), take_copy)) );
  //We use dynamic_cast<> in case of multiple inheritance.
}

} /* namespace Glib */


namespace Gst
{


/* The *_Class implementation: */

const Glib::Class& Queue2_Class::init()
{
  if(!gtype_) // create the GType if necessary
  {
    // Glib::Class has to know the class init function to clone custom types.
    class_init_func_ = &Queue2_Class::class_init_function;

    // This is actually just optimized away, apparently with no harm.
    // Make sure that the parent type has been created.
    //CppClassParent::CppObjectType::get_type();

    // Create the wrapper type, with the same class/instance size as the base type.
    register_derived_type(gst_queue2_gstreamermm_get_type());

    // Add derived versions of interfaces, if the C type implements any interfaces:

  }

  return *this;
}


void Queue2_Class::class_init_function(void* g_class, void* class_data)
{
  const auto klass = static_cast<BaseClassType*>(g_class);
  CppClassParent::class_init_function(klass, class_data);


}


Glib::ObjectBase* Queue2_Class::wrap_new(GObject* object)
{
  return new Queue2((GstQueue2*)object);
}


/* The implementation: */

GstQueue2* Queue2::gobj_copy()
{
  reference();
  return gobj();
}

Queue2::Queue2(const Glib::ConstructParams& construct_params)
:
  Gst::Element(construct_params)
{

}

Queue2::Queue2(GstQueue2* castitem)
:
  Gst::Element((GstElement*)(castitem))
{}


Queue2::Queue2(Queue2&& src) noexcept
: Gst::Element(std::move(src))
{}

Queue2& Queue2::operator=(Queue2&& src) noexcept
{
  Gst::Element::operator=(std::move(src));
  return *this;
}


Queue2::~Queue2() noexcept
{}


Queue2::CppClassType Queue2::queue2_class_; // initialize static member

GType Queue2::get_type()
{
  return queue2_class_.init().get_type();
}


GType Queue2::get_base_type()
{
  return gst_queue2_gstreamermm_get_type();
}


Glib::RefPtr<Queue2> Queue2::create()
{
  return Glib::RefPtr<Queue2>( new Queue2() );
}

Glib::RefPtr<Queue2> Queue2::create(const Glib::ustring& name)
{
  return Glib::RefPtr<Queue2>( new Queue2(name) );
}


Glib::PropertyProxy_ReadOnly< guint > Queue2::property_current_level_buffers() const
{
  return Glib::PropertyProxy_ReadOnly< guint >(this, "current-level-buffers");
}

Glib::PropertyProxy_ReadOnly< guint > Queue2::property_current_level_bytes() const
{
  return Glib::PropertyProxy_ReadOnly< guint >(this, "current-level-bytes");
}

Glib::PropertyProxy_ReadOnly< guint64 > Queue2::property_current_level_time() const
{
  return Glib::PropertyProxy_ReadOnly< guint64 >(this, "current-level-time");
}

Glib::PropertyProxy< guint > Queue2::property_max_size_buffers() 
{
  return Glib::PropertyProxy< guint >(this, "max-size-buffers");
}

Glib::PropertyProxy_ReadOnly< guint > Queue2::property_max_size_buffers() const
{
  return Glib::PropertyProxy_ReadOnly< guint >(this, "max-size-buffers");
}

Glib::PropertyProxy< guint > Queue2::property_max_size_bytes() 
{
  return Glib::PropertyProxy< guint >(this, "max-size-bytes");
}

Glib::PropertyProxy_ReadOnly< guint > Queue2::property_max_size_bytes() const
{
  return Glib::PropertyProxy_ReadOnly< guint >(this, "max-size-bytes");
}

Glib::PropertyProxy< guint64 > Queue2::property_max_size_time() 
{
  return Glib::PropertyProxy< guint64 >(this, "max-size-time");
}

Glib::PropertyProxy_ReadOnly< guint64 > Queue2::property_max_size_time() const
{
  return Glib::PropertyProxy_ReadOnly< guint64 >(this, "max-size-time");
}

Glib::PropertyProxy< bool > Queue2::property_use_buffering() 
{
  return Glib::PropertyProxy< bool >(this, "use-buffering");
}

Glib::PropertyProxy_ReadOnly< bool > Queue2::property_use_buffering() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "use-buffering");
}

Glib::PropertyProxy< bool > Queue2::property_use_tags_bitrate() 
{
  return Glib::PropertyProxy< bool >(this, "use-tags-bitrate");
}

Glib::PropertyProxy_ReadOnly< bool > Queue2::property_use_tags_bitrate() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "use-tags-bitrate");
}

Glib::PropertyProxy< bool > Queue2::property_use_rate_estimate() 
{
  return Glib::PropertyProxy< bool >(this, "use-rate-estimate");
}

Glib::PropertyProxy_ReadOnly< bool > Queue2::property_use_rate_estimate() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "use-rate-estimate");
}

Glib::PropertyProxy< int > Queue2::property_low_percent() 
{
  return Glib::PropertyProxy< int >(this, "low-percent");
}

Glib::PropertyProxy_ReadOnly< int > Queue2::property_low_percent() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "low-percent");
}

Glib::PropertyProxy< int > Queue2::property_high_percent() 
{
  return Glib::PropertyProxy< int >(this, "high-percent");
}

Glib::PropertyProxy_ReadOnly< int > Queue2::property_high_percent() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "high-percent");
}

Glib::PropertyProxy< Glib::ustring > Queue2::property_temp_template() 
{
  return Glib::PropertyProxy< Glib::ustring >(this, "temp-template");
}

Glib::PropertyProxy_ReadOnly< Glib::ustring > Queue2::property_temp_template() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::ustring >(this, "temp-template");
}

Glib::PropertyProxy_ReadOnly< Glib::ustring > Queue2::property_temp_location() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::ustring >(this, "temp-location");
}

Glib::PropertyProxy< bool > Queue2::property_temp_remove() 
{
  return Glib::PropertyProxy< bool >(this, "temp-remove");
}

Glib::PropertyProxy_ReadOnly< bool > Queue2::property_temp_remove() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "temp-remove");
}

Glib::PropertyProxy< guint64 > Queue2::property_ring_buffer_max_size() 
{
  return Glib::PropertyProxy< guint64 >(this, "ring-buffer-max-size");
}

Glib::PropertyProxy_ReadOnly< guint64 > Queue2::property_ring_buffer_max_size() const
{
  return Glib::PropertyProxy_ReadOnly< guint64 >(this, "ring-buffer-max-size");
}

Glib::PropertyProxy_ReadOnly< gint64 > Queue2::property_avg_in_rate() const
{
  return Glib::PropertyProxy_ReadOnly< gint64 >(this, "avg-in-rate");
}


} // namespace Gst

#endif // GSTREAMERMM_DISABLE_DEPRECATED


