// Generated by gmmproc 2.50.1 -- DO NOT MODIFY!
#ifndef _GSTREAMERMM_MESSAGE_P_H
#define _GSTREAMERMM_MESSAGE_P_H


#include <gstreamermm/private/miniobject_p.h>


#endif /* _GSTREAMERMM_MESSAGE_P_H */

