// Generated by gmmproc 2.50.1 -- DO NOT MODIFY!
#ifndef _GSTREAMERMM_COLORBALANCE_P_H
#define _GSTREAMERMM_COLORBALANCE_P_H


#include <glibmm/private/interface_p.h>

namespace Gst
{

class ColorBalance_Class : public Glib::Interface_Class
{
public:
  using CppObjectType = ColorBalance;
  using BaseObjectType = GstColorBalance;
  using BaseClassType = GstColorBalanceInterface;
  using CppClassParent = Glib::Interface_Class;

  friend class ColorBalance;

  const Glib::Interface_Class& init();

  static void iface_init_function(void* g_iface, void* iface_data);

  static Glib::ObjectBase* wrap_new(GObject*);

protected:

  //Callbacks (default signal handlers):
  //These will call the *_impl member methods, which will then call the existing default signal callbacks, if any.
  //You could prevent the original default signal handlers being called by overriding the *_impl method.
  static void value_changed_callback(GstColorBalance* self, GstColorBalanceChannel* p0, gint p1);

  //Callbacks (virtual functions):
  static void set_value_vfunc_callback(GstColorBalance* self, GstColorBalanceChannel* balance, gint value);
  static gint get_value_vfunc_callback(GstColorBalance* self, GstColorBalanceChannel* balance);
  static GstColorBalanceType get_balance_type_vfunc_callback(GstColorBalance* self);
  static const GList* list_channels_vfunc_callback(GstColorBalance* self);
  };


} // namespace Gst


#endif /* _GSTREAMERMM_COLORBALANCE_P_H */

