// Generated by gmmproc 2.50.1 -- DO NOT MODIFY!


#include <gstreamermmconfig.h>
#ifndef GSTREAMERMM_DISABLE_DEPRECATED


#include <glibmm.h>

#include <gstreamermm/xvimagesink.h>
#include <gstreamermm/private/xvimagesink_p.h>


// Generated by generate_plugin_gmmproc_file. Don't edit this file.


extern "C"
{

GType gst_xv_image_sink_gstreamermm_get_type()
{
  static GType type = 0;
  GstElementFactory* factory = 0;
  GstPluginFeature* feature = 0;

  if(!type)
  {
    factory = gst_element_factory_find("xvimagesink");
    // Make sure that the feature is actually loaded:
    if(factory)
    {
      feature =
        gst_plugin_feature_load(GST_PLUGIN_FEATURE(factory));

      g_object_unref(factory);
      factory = GST_ELEMENT_FACTORY(feature);
      type = gst_element_factory_get_element_type(factory);
      g_object_unref(factory);
    }
  }

  return type;
}

} // extern "C"

namespace Gst
{

XvImageSink::XvImageSink()
: // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gst::VideoSink(Glib::ConstructParams(xvimagesink_class_.init(), "name",static_cast<char*>(0), nullptr))
{}

XvImageSink::XvImageSink(const Glib::ustring& name)
: // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gst::VideoSink(Glib::ConstructParams(xvimagesink_class_.init(), "name",name.c_str(), nullptr))
{}

}

namespace
{
} // anonymous namespace


namespace Glib
{

Glib::RefPtr<Gst::XvImageSink> wrap(GstXvImageSink* object, bool take_copy)
{
  return Glib::RefPtr<Gst::XvImageSink>( dynamic_cast<Gst::XvImageSink*> (Glib::wrap_auto ((GObject*)(object), take_copy)) );
  //We use dynamic_cast<> in case of multiple inheritance.
}

} /* namespace Glib */


namespace Gst
{


/* The *_Class implementation: */

const Glib::Class& XvImageSink_Class::init()
{
  if(!gtype_) // create the GType if necessary
  {
    // Glib::Class has to know the class init function to clone custom types.
    class_init_func_ = &XvImageSink_Class::class_init_function;

    // This is actually just optimized away, apparently with no harm.
    // Make sure that the parent type has been created.
    //CppClassParent::CppObjectType::get_type();

    // Create the wrapper type, with the same class/instance size as the base type.
    register_derived_type(gst_xv_image_sink_gstreamermm_get_type());

    // Add derived versions of interfaces, if the C type implements any interfaces:
  Gst::Navigation::add_interface(get_type());
  Gst::VideoOverlay::add_interface(get_type());
  Gst::ColorBalance::add_interface(get_type());

  }

  return *this;
}


void XvImageSink_Class::class_init_function(void* g_class, void* class_data)
{
  const auto klass = static_cast<BaseClassType*>(g_class);
  CppClassParent::class_init_function(klass, class_data);


}


Glib::ObjectBase* XvImageSink_Class::wrap_new(GObject* object)
{
  return new XvImageSink((GstXvImageSink*)object);
}


/* The implementation: */

GstXvImageSink* XvImageSink::gobj_copy()
{
  reference();
  return gobj();
}

XvImageSink::XvImageSink(const Glib::ConstructParams& construct_params)
:
  Gst::VideoSink(construct_params)
{

}

XvImageSink::XvImageSink(GstXvImageSink* castitem)
:
  Gst::VideoSink((GstVideoSink*)(castitem))
{}


XvImageSink::XvImageSink(XvImageSink&& src) noexcept
: Gst::VideoSink(std::move(src))
  , Gst::Navigation(std::move(src))
  , Gst::VideoOverlay(std::move(src))
  , Gst::ColorBalance(std::move(src))
{}

XvImageSink& XvImageSink::operator=(XvImageSink&& src) noexcept
{
  Gst::VideoSink::operator=(std::move(src));
  Gst::Navigation::operator=(std::move(src));
  Gst::VideoOverlay::operator=(std::move(src));
  Gst::ColorBalance::operator=(std::move(src));
  return *this;
}


XvImageSink::~XvImageSink() noexcept
{}


XvImageSink::CppClassType XvImageSink::xvimagesink_class_; // initialize static member

GType XvImageSink::get_type()
{
  return xvimagesink_class_.init().get_type();
}


GType XvImageSink::get_base_type()
{
  return gst_xv_image_sink_gstreamermm_get_type();
}


Glib::RefPtr<XvImageSink> XvImageSink::create()
{
  return Glib::RefPtr<XvImageSink>( new XvImageSink() );
}

Glib::RefPtr<XvImageSink> XvImageSink::create(const Glib::ustring& name)
{
  return Glib::RefPtr<XvImageSink>( new XvImageSink(name) );
}


Glib::PropertyProxy< int > XvImageSink::property_contrast() 
{
  return Glib::PropertyProxy< int >(this, "contrast");
}

Glib::PropertyProxy_ReadOnly< int > XvImageSink::property_contrast() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "contrast");
}

Glib::PropertyProxy< int > XvImageSink::property_brightness() 
{
  return Glib::PropertyProxy< int >(this, "brightness");
}

Glib::PropertyProxy_ReadOnly< int > XvImageSink::property_brightness() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "brightness");
}

Glib::PropertyProxy< int > XvImageSink::property_hue() 
{
  return Glib::PropertyProxy< int >(this, "hue");
}

Glib::PropertyProxy_ReadOnly< int > XvImageSink::property_hue() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "hue");
}

Glib::PropertyProxy< int > XvImageSink::property_saturation() 
{
  return Glib::PropertyProxy< int >(this, "saturation");
}

Glib::PropertyProxy_ReadOnly< int > XvImageSink::property_saturation() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "saturation");
}

Glib::PropertyProxy< Glib::ustring > XvImageSink::property_display() 
{
  return Glib::PropertyProxy< Glib::ustring >(this, "display");
}

Glib::PropertyProxy_ReadOnly< Glib::ustring > XvImageSink::property_display() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::ustring >(this, "display");
}

Glib::PropertyProxy< bool > XvImageSink::property_synchronous() 
{
  return Glib::PropertyProxy< bool >(this, "synchronous");
}

Glib::PropertyProxy_ReadOnly< bool > XvImageSink::property_synchronous() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "synchronous");
}

Glib::PropertyProxy< Glib::ustring > XvImageSink::property_pixel_aspect_ratio() 
{
  return Glib::PropertyProxy< Glib::ustring >(this, "pixel-aspect-ratio");
}

Glib::PropertyProxy_ReadOnly< Glib::ustring > XvImageSink::property_pixel_aspect_ratio() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::ustring >(this, "pixel-aspect-ratio");
}

Glib::PropertyProxy< bool > XvImageSink::property_force_aspect_ratio() 
{
  return Glib::PropertyProxy< bool >(this, "force-aspect-ratio");
}

Glib::PropertyProxy_ReadOnly< bool > XvImageSink::property_force_aspect_ratio() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "force-aspect-ratio");
}

Glib::PropertyProxy< bool > XvImageSink::property_handle_events() 
{
  return Glib::PropertyProxy< bool >(this, "handle-events");
}

Glib::PropertyProxy_ReadOnly< bool > XvImageSink::property_handle_events() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "handle-events");
}

Glib::PropertyProxy< Glib::ustring > XvImageSink::property_device() 
{
  return Glib::PropertyProxy< Glib::ustring >(this, "device");
}

Glib::PropertyProxy_ReadOnly< Glib::ustring > XvImageSink::property_device() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::ustring >(this, "device");
}

Glib::PropertyProxy_ReadOnly< Glib::ustring > XvImageSink::property_device_name() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::ustring >(this, "device-name");
}

Glib::PropertyProxy< bool > XvImageSink::property_handle_expose() 
{
  return Glib::PropertyProxy< bool >(this, "handle-expose");
}

Glib::PropertyProxy_ReadOnly< bool > XvImageSink::property_handle_expose() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "handle-expose");
}

Glib::PropertyProxy< bool > XvImageSink::property_double_buffer() 
{
  return Glib::PropertyProxy< bool >(this, "double-buffer");
}

Glib::PropertyProxy_ReadOnly< bool > XvImageSink::property_double_buffer() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "double-buffer");
}

Glib::PropertyProxy< bool > XvImageSink::property_autopaint_colorkey() 
{
  return Glib::PropertyProxy< bool >(this, "autopaint-colorkey");
}

Glib::PropertyProxy_ReadOnly< bool > XvImageSink::property_autopaint_colorkey() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "autopaint-colorkey");
}

Glib::PropertyProxy< int > XvImageSink::property_colorkey() 
{
  return Glib::PropertyProxy< int >(this, "colorkey");
}

Glib::PropertyProxy_ReadOnly< int > XvImageSink::property_colorkey() const
{
  return Glib::PropertyProxy_ReadOnly< int >(this, "colorkey");
}

Glib::PropertyProxy< bool > XvImageSink::property_draw_borders() 
{
  return Glib::PropertyProxy< bool >(this, "draw-borders");
}

Glib::PropertyProxy_ReadOnly< bool > XvImageSink::property_draw_borders() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "draw-borders");
}

Glib::PropertyProxy_ReadOnly< guint64 > XvImageSink::property_window_width() const
{
  return Glib::PropertyProxy_ReadOnly< guint64 >(this, "window-width");
}

Glib::PropertyProxy_ReadOnly< guint64 > XvImageSink::property_window_height() const
{
  return Glib::PropertyProxy_ReadOnly< guint64 >(this, "window-height");
}


} // namespace Gst

#endif // GSTREAMERMM_DISABLE_DEPRECATED


