// Generated by gmmproc 2.50.1 -- DO NOT MODIFY!


#include <gstreamermmconfig.h>
#ifndef GSTREAMERMM_DISABLE_DEPRECATED


#include <glibmm.h>

#include <gstreamermm/concat.h>
#include <gstreamermm/private/concat_p.h>


// Generated by generate_plugin_gmmproc_file. Don't edit this file.


extern "C"
{

GType gst_concat_gstreamermm_get_type()
{
  static GType type = 0;
  GstElementFactory* factory = 0;
  GstPluginFeature* feature = 0;

  if(!type)
  {
    factory = gst_element_factory_find("concat");
    // Make sure that the feature is actually loaded:
    if(factory)
    {
      feature =
        gst_plugin_feature_load(GST_PLUGIN_FEATURE(factory));

      g_object_unref(factory);
      factory = GST_ELEMENT_FACTORY(feature);
      type = gst_element_factory_get_element_type(factory);
      g_object_unref(factory);
    }
  }

  return type;
}

} // extern "C"

namespace Gst
{

Concat::Concat()
: // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gst::Element(Glib::ConstructParams(concat_class_.init(), "name",static_cast<char*>(0), nullptr))
{}

Concat::Concat(const Glib::ustring& name)
: // Mark this class as non-derived to allow C++ vfuncs to be skipped.
  Glib::ObjectBase(nullptr),
  Gst::Element(Glib::ConstructParams(concat_class_.init(), "name",name.c_str(), nullptr))
{}

}

namespace
{
} // anonymous namespace


namespace Glib
{

Glib::RefPtr<Gst::Concat> wrap(GstConcat* object, bool take_copy)
{
  return Glib::RefPtr<Gst::Concat>( dynamic_cast<Gst::Concat*> (Glib::wrap_auto ((GObject*)(object), take_copy)) );
  //We use dynamic_cast<> in case of multiple inheritance.
}

} /* namespace Glib */


namespace Gst
{


/* The *_Class implementation: */

const Glib::Class& Concat_Class::init()
{
  if(!gtype_) // create the GType if necessary
  {
    // Glib::Class has to know the class init function to clone custom types.
    class_init_func_ = &Concat_Class::class_init_function;

    // This is actually just optimized away, apparently with no harm.
    // Make sure that the parent type has been created.
    //CppClassParent::CppObjectType::get_type();

    // Create the wrapper type, with the same class/instance size as the base type.
    register_derived_type(gst_concat_gstreamermm_get_type());

    // Add derived versions of interfaces, if the C type implements any interfaces:

  }

  return *this;
}


void Concat_Class::class_init_function(void* g_class, void* class_data)
{
  const auto klass = static_cast<BaseClassType*>(g_class);
  CppClassParent::class_init_function(klass, class_data);


}


Glib::ObjectBase* Concat_Class::wrap_new(GObject* object)
{
  return new Concat((GstConcat*)object);
}


/* The implementation: */

GstConcat* Concat::gobj_copy()
{
  reference();
  return gobj();
}

Concat::Concat(const Glib::ConstructParams& construct_params)
:
  Gst::Element(construct_params)
{

}

Concat::Concat(GstConcat* castitem)
:
  Gst::Element((GstElement*)(castitem))
{}


Concat::Concat(Concat&& src) noexcept
: Gst::Element(std::move(src))
{}

Concat& Concat::operator=(Concat&& src) noexcept
{
  Gst::Element::operator=(std::move(src));
  return *this;
}


Concat::~Concat() noexcept
{}


Concat::CppClassType Concat::concat_class_; // initialize static member

GType Concat::get_type()
{
  return concat_class_.init().get_type();
}


GType Concat::get_base_type()
{
  return gst_concat_gstreamermm_get_type();
}


Glib::RefPtr<Concat> Concat::create()
{
  return Glib::RefPtr<Concat>( new Concat() );
}

Glib::RefPtr<Concat> Concat::create(const Glib::ustring& name)
{
  return Glib::RefPtr<Concat>( new Concat(name) );
}


Glib::PropertyProxy_ReadOnly< Glib::RefPtr<Gst::Pad> > Concat::property_active_pad() const
{
  return Glib::PropertyProxy_ReadOnly< Glib::RefPtr<Gst::Pad> >(this, "active-pad");
}

Glib::PropertyProxy< bool > Concat::property_adjust_base() 
{
  return Glib::PropertyProxy< bool >(this, "adjust-base");
}

Glib::PropertyProxy_ReadOnly< bool > Concat::property_adjust_base() const
{
  return Glib::PropertyProxy_ReadOnly< bool >(this, "adjust-base");
}


} // namespace Gst

#endif // GSTREAMERMM_DISABLE_DEPRECATED


